<template>
    <v-card>
        <Head title="All Posts"/>
        <v-row dense class="d-flex child-flex">
            <template>
                <v-data-table :headers="headers" :items="posts" sort-by="sn" class="elevation-1">
                    <template v-slot:item.sn="{ index }">
                        {{ index + 1 }}
                    </template>
                    <template v-slot:item.media="{ item }">
                        <v-img :lazy-src="item.media.url"
                               max-height="45" max-width="45"
                               :src="item.media.url"></v-img>
                    </template>
                    <template v-slot:item.active="{ item }">
                        <v-btn @click="changeStatus(item)" text :color="item.active ? 'success':'warning'">
                            {{ item.active ? 'Public' : 'Draft' }}
                        </v-btn>
                    </template>
                    <template v-slot:item.description="{ item }">
                        <v-tooltip bottom max-width="300">
                            <template v-slot:activator="{ on, attrs }">
                                    <span v-bind="attrs" v-on="on">
                                        {{ item.description | trim(45) }}
                                    </span>

                            </template>
                            <span>{{ item.description }}</span>
                        </v-tooltip>
                    </template>
                    <template v-slot:item.action="{ item }">
                        <v-icon @click="$go('post.edit', {article: item.id})" color="primary" small
                                class="mr-2">
                            mdi-pencil
                        </v-icon>
                        <v-icon color="red" small @click="deleteItem(item)">
                            mdi-delete
                        </v-icon>
                    </template>
                    <template v-slot:no-data>
                        No article has been created yet
                    </template>
                </v-data-table>
            </template>
        </v-row>
    </v-card>
</template>


<script>
import DashboardLayout from "../../Components/Layouts/Dashboard.vue";
import Post from "./Post.vue";


export default {
    name: "PostIndex",
    layout: [DashboardLayout, Post],
    data() {
        return {
            posts: this.$page.props.posts,
            dialogDelete: false,
            deleteIndex: -1,
            headers: [
                {text: 'S/N', align: 'center', value: 'sn', sortable: false},
                {text: 'Caption', value: `media`},
                {text: 'Title', align: 'start', sortable: false, value: 'title'},
                {text: 'Description', value: `description`},
                {text: 'Status', align: 'center', value: 'active'},
                {text: 'Action', value: 'action', sortable: false, width: '100'},
            ],
        }
    },
    computed: {},

    watch: {
        dialogDelete(val) {
            val || this.closeDelete()
        },
    },

    methods: {
        nextStatus (status) {
            return status ? 'Désactiver' : 'Activer'
        },
        deleteItem(item) {
            this.deleteIndex = this.posts.indexOf(item)
            this.dialogDelete = true
        },
        deleteItemConfirm() {
            this.axios.post(this.$route('post.status', {article:this.posts[this.deleteIndex].id}))
                .then(res => res.data)
                .then(data => {
                    if (data.status === 'success') {
                        this.$toast.success("Suppression réussie.")
                        this.posts.splice(this.deleteIndex, 1)
                        this.closeDelete()
                    }
                })
                .catch(err => {
                    this.$toast.error(`Une erreur s'est produite lors de la suppression de l'article: ${err.toString()}`)
                })
        },
        closeDelete() {
            this.dialogDelete = false
            this.$nextTick(() => {
                this.deleteIndex = -1
            })
        },
        changeStatus (item) {
            axios.post(this.$route('post.status', {article: item.id}))
                .then(res => res.data)
                .then(data => {
                    if (data.status === 'success') {
                        this.$toast.success("Statut mis à jour.")
                        this.posts.splice(this.posts.indexOf(item), 1, data.data)
                    }
                })
                .catch(err => {
                    this.$toast.error(`Une erreur s'est produite lors de la mise à jour de l'état de l'article: ${err.toString()}`)
                })
        },
    }
}
</script>


<style scoped>

</style>
